<?php
/**
 * The library
 *
 * @package WordPress
 * @subpackage BlogoLife
 * @since BlogoLife 3.0.0
 * @author Valeriu Tihai
 * @author Stylish WordPress Themes
 * @link https://stylishwp.com
 */


/*------------------------------------------------------------
	Get Theme Version
============================================================*/
if ( ! function_exists( 'blogolife_get_theme_version' ) ) :
	function blogolife_get_theme_version() {
		$blogolife_theme = wp_get_theme();
		return $blogolife_theme->get( 'Version' );
	}
endif;


/*------------------------------------------------------------
	Prints HTML with date information for current post
============================================================*/
if ( ! function_exists( 'blogolife_entry_date' ) ) :
	function blogolife_entry_date() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}
		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			get_the_date(),
			esc_attr( get_the_modified_date( 'c' ) ),
			get_the_modified_date()
		);
		printf( '<span class="posted-on f-link"><a href="%1$s" rel="bookmark">%2$s</a></span>',
			esc_url( get_permalink() ),
			$time_string
		);
	}
endif;


/*------------------------------------------------------------
	Prints HTML with Author Name information for current post
============================================================*/
if ( ! function_exists( 'blogolife_entry_author' ) ) :
	function blogolife_entry_author() {
		$author_avatar_size = apply_filters( 'blogolife_author_avatar_size', 20 );
		printf( '<span class="posted-by"><span class="author vcard">%1$s <a class="url fn n" href="%2$s">%3$s</a></span></span>',
			get_avatar( get_the_author_meta( 'user_email' ), $author_avatar_size ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			get_the_author()
		);
	}
endif;


/*------------------------------------------------------------
	Prints HTML for post comments
============================================================*/
if ( ! function_exists( 'blogolife_entry_comments' ) ) :
	function blogolife_entry_comments() {
		if ( ! is_singular() && ! post_password_required() && ( comments_open() ) ) {
			echo '<span class="comments-link f-link ">';
			comments_popup_link(
				__( 'Add a Comment', 'blogolife' ),
				__( '1 Comment', 'blogolife' ),
				__( '% Comments', 'blogolife' ),
				'comments_popup_link',
				__( 'Comments are closed', 'blogolife' )
			);
			echo '</span>';
		}
	}
endif;


/*------------------------------------------------------------
	Prints HTML with category for current post.
============================================================*/
if ( ! function_exists( 'blogolife_entry_taxonomies_categories' ) ) :
	function blogolife_entry_taxonomies_categories() {
		$categories_list = get_the_category_list( _x(  ', ', 'Used between list items, there is a space after the comma.', 'blogolife' ) );
		if ( $categories_list && blogolife_categorized_blog() ) {
			printf( '<div class="cat-links taxonomies-links"><b class="screen-reader-text">%1$s</b>%2$s</div>',
				_x( 'Categories:', 'Used before category names.', 'blogolife' ),
				$categories_list
			);
		}
	}
endif;


/*------------------------------------------------------------
	Prints HTML with tags for current post.
============================================================*/
if ( ! function_exists( 'blogolife_entry_taxonomies_tags' ) ) :
	function blogolife_entry_taxonomies_tags() {
		$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'blogolife' ) );
		if ( $tags_list ) {
			printf( '<div class="tags-links taxonomies-links"><b class="screen-reader-text">%1$s </b>%2$s</div>',
				_x( 'Tags:', 'Used before tag names.', 'blogolife' ),
				$tags_list
			);
		}
	}
endif;


/*------------------------------------------------------------
	Determines whether blog/site has more than one category.
============================================================*/
if ( ! function_exists( 'blogolife_categorized_blog' ) ) :
	function blogolife_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'blogolife_categories' ) ) ) {
			// Create an array of all the categories that are attached to posts.
			$all_the_cool_cats = get_categories( array(
				'fields'     => 'ids',
				// We only need to know if there is more than one category.
				'number'     => 2,
			) );
			// Count the number of categories that are attached to the posts.
			$all_the_cool_cats = count( $all_the_cool_cats );
			set_transient( 'blogolife_categories', $all_the_cool_cats );
		}
		if ( $all_the_cool_cats > 1 ) {
			// This blog has more than 1 category so blogolife_categorized_blog should return true.
			return true;
		} else {
			// This blog has only 1 category so blogolife_categorized_blog should return false.
			return false;
		}
	}
endif;


/*------------------------------------------------------------
	Flushes out the transients used in blogolife_categorized_blog().
============================================================*/
function blogolife_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'blogolife_categories' );
}
add_action( 'edit_category', 'blogolife_category_transient_flusher' );
add_action( 'save_post',     'blogolife_category_transient_flusher' );


/*------------------------------------------------------------
	Flushes out the transients for Latest Comments and Popular Posts
============================================================*/

function blogolife_lcp_popular_lcomments_transient_flusher( $comment_ID, $comment_approved ) {
	if( 1 === $comment_approved ){
		delete_transient( 'blogolife_popular_posts' );
		delete_transient( 'blogolife_latest_comments' );
	}
}
function blogolife_lcp_popular_lcomments_transient_flushert ($comment_ID) {
	delete_transient( 'blogolife_popular_posts' );
	delete_transient( 'blogolife_latest_comments' );
}
add_action ( 'comment_post', 'blogolife_lcp_popular_lcomments_transient_flusher', 10, 2 );
add_action ( 'trashed_comment', 'blogolife_lcp_popular_lcomments_transient_flushert' );
add_action ( 'untrashed_comment', 'blogolife_lcp_popular_lcomments_transient_flushert' );
add_action ( 'deleted_comment', 'blogolife_lcp_popular_lcomments_transient_flushert' );

/*------------------------------------------------------------
	Flushes out the transients for Latest Posts
============================================================*/
function blogolife_lcp_latest_posts_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	delete_transient( 'blogolife_latest_posts' );
}
add_action( 'save_post',     'blogolife_lcp_latest_posts_transient_flusher' );


/*------------------------------------------------------------
	Add CSS class to menus for submenu indicator
============================================================*/

class Blogolife_Walker_Mobile_Menu extends Walker_Nav_Menu {
	function start_lvl(&$output, $depth = 0, $args = Array() ) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class=\"vertical nested menu sub-menu\">\n";
	}
}
class Blogolife_Walker_Main_Menu extends Walker_Nav_Menu {
	function start_lvl(&$output, $depth = 0, $args = Array() ) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class=\"menu sub-menu\">\n";
	}
}


/*------------------------------------------------------------
	Returns the post format of a post.
============================================================*/
if ( ! function_exists( 'blogolife_postformat_icon' ) ) {
	function blogolife_postformat_icon($postformat) {
		switch ($postformat) {
			case 'aside':
				$postformaticon = 'fa fa-file-text-o';
				break;
			case 'chat':
				$postformaticon = 'fa fa-weixin';
				break;
			case 'gallery':
			case 'image':
				$postformaticon = 'fa fa-file-image-o';
				break;
			case 'link':
				$postformaticon = 'fa fa-link';
				break;
			case 'quote':
				$postformaticon = 'fa fa-quote-left';
				break;
			case 'status':
				$postformaticon = 'fa fa-file-text-o';
				break;
			case 'video':
				$postformaticon = 'fa fa-file-video-o';
				break;
			case 'audio':
				$postformaticon = 'fa fa-file-audio-o';
				break;
			default:
				$postformaticon = 'fa fa-file-text-o';
		}
		return $postformaticon;
	}
}


/*------------------------------------------------------------
	Comments callback
============================================================*/
if ( ! function_exists( 'blogolife_list_comment' ) ) :
	function blogolife_list_comment($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		extract($args, EXTR_SKIP);

		if ( 'div' == $args['style'] ) {
			$tag = 'div';
			$add_below = 'comment';
		} else {
			$tag = 'li';
			$add_below = 'div-comment';
		}
	?>
		<<?php echo $tag ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
			<?php if ( 'div' != $args['style'] ) : ?>
				<div id="div-comment-<?php comment_ID() ?>" class="comment-body">
			<?php endif; ?>
			<article>

			<header class="entry-header comment-author vcard">
				<?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
				<?php printf( '<span class="comment-author-name fn">%s</span>', get_comment_author_link() ); ?>
			</header>
			<div class="entry-content">
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'blogolife' ); ?></em>
					<br />
				<?php endif; ?>
					<?php comment_text(); ?>
			</div>

			<footer class="entry-footer comment-meta commentmetadata">
				<span class="posted-on f-link">
					<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
						<?php printf( __('%1$s at %2$s', 'blogolife'), get_comment_date(),  get_comment_time() ); ?>
					</a>
				</span>
				<span class="edit-link f-link">
					<?php edit_comment_link( __( 'Edit', 'blogolife' ), '', '' ); ?>
				</span>
				<span class="reply-link f-link">
					<?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</span>
			</footer>

		</article>
		<?php if ( 'div' != $args['style'] ) : ?>
			</div>
		<?php endif; ?>
	<?php
	}
endif;


/*------------------------------------------------------------
	Comments Navigation
============================================================*/
if ( ! function_exists( 'blogolife_the_comments_navigation' ) ) :
	function blogolife_the_comments_navigation( $args = array(), $navigation = '' ) {
		// Are there comments to navigate through?
		if ( get_comment_pages_count() > 1 ) {
			$navigation = '<div class="post_comments-nav-links panel clearfix">';
			$args = wp_parse_args( $args, array(
				'prev_text'          => __( 'Older comments', 'blogolife' ),
				'next_text'          => __( 'Newer comments', 'blogolife' ),
				'screen_reader_text' => __( 'Comments navigation', 'blogolife' ),
			) );
			$prev_link = get_previous_comments_link( $args['prev_text'] );
			$next_link = get_next_comments_link( $args['next_text'] );
			if ( $prev_link ) {
				$navigation .= '<span class="comments-nav-prev float-left">' . $prev_link . '</span>';
			}
			if ( $next_link ) {
				$navigation .= '<span class="comments-nav-next float-right">' . $next_link . '</span>';
			}
			$navigation = _navigation_markup( $navigation, 'comment-navigation', $args['screen_reader_text'] );
			$navigation .= '</div>';
		}
		echo $navigation;
	}
endif;


/*------------------------------------------------------------
	Display Navigation for post, pages, search
============================================================*/
if ( ! function_exists( 'blogolife_content_navigation' ) ) :
	function blogolife_content_navigation( $nav_id ) { ?>

				<div class="post_comments-nav-links panel clearfix">
					<span class="post-nav-prev float-left">
						<?php previous_post_link( '%link', __( 'Previous', 'blogolife' ) ); ?>
					</span><!-- /.post-nav-prev -->

					<span class="post-nav-next float-right">
						<?php next_post_link( '%link', __( 'Next', 'blogolife' ) ); ?>
					</span><!-- /.post-nav-next -->
				</div>

		<?php
	}
endif;


/*------------------------------------------------------------
	Numeric Post Navigation
============================================================*/
if ( ! function_exists( 'blogolife_page_navigation' ) ) :
	function blogolife_page_navigation($before = '', $after = '') {
		global $wpdb, $wp_query;
		$request = $wp_query->request;
		$posts_per_page = intval(get_query_var('posts_per_page'));
		$paged = intval(get_query_var('paged'));
		$numposts = $wp_query->found_posts;
		$max_page = $wp_query->max_num_pages;
		if ( $numposts <= $posts_per_page ) { return; }
		if(empty($paged) || $paged == 0) {
			$paged = 1;
		}
		$pages_to_show = 7;
		$pages_to_show_minus_1 = $pages_to_show-1;
		$half_page_start = floor($pages_to_show_minus_1/2);
		$half_page_end = ceil($pages_to_show_minus_1/2);
		$start_page = $paged - $half_page_start;
		if($start_page <= 0) {
			$start_page = 1;
		}
		$end_page = $paged + $half_page_end;
		if(($end_page - $start_page) != $pages_to_show_minus_1) {
			$end_page = $start_page + $pages_to_show_minus_1;
		}
		if($end_page > $max_page) {
			$start_page = $max_page - $pages_to_show_minus_1;
			$end_page = $max_page;
		}
		if($start_page <= 0) {
			$start_page = 1;
		}
		echo $before.'<nav class="page-navigation"><ul class="pagination text-center">'."";

		echo '<li>';
			previous_posts_link( __('Previous', 'blogolife') );
		echo '</li>';
		for($i = $start_page; $i  <= $end_page; $i++) {
			if($i == $paged) {
				echo '<li class="current"> '.$i.' </li>';
			} else {
				echo '<li><a href="'.get_pagenum_link($i).'">'.$i.'</a></li>';
			}
		}
		echo '<li>';
			next_posts_link( __('Next', 'blogolife') );
		echo '</li>';
		echo '</ul></nav>'.$after."";
	}
endif;


/*------------------------------------------------------------
	Convert HEX to RGB.
============================================================*/
if ( ! function_exists( 'blogolife_hex2rgb' ) ) :
	function blogolife_hex2rgb( $color ) {
		$color = trim( $color, '#' );
		if ( strlen( $color ) == 3 ) {
			$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
			$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
			$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
		} else if ( strlen( $color ) == 6 ) {
			$r = hexdec( substr( $color, 0, 2 ) );
			$g = hexdec( substr( $color, 2, 2 ) );
			$b = hexdec( substr( $color, 4, 2 ) );
		} else {
			return array();
		}
		return array( 'red' => $r, 'green' => $g, 'blue' => $b );
	}
endif;

/*------------------------------------------------------------
	Adds custom classes to the array of body classes.
============================================================*/
if ( ! function_exists( 'blogolife_body_classes' ) ) :
	function blogolife_body_classes( $classes ) {
		global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;

		// Adds a class of custom-background-image to sites with a custom background image.
		if ( get_background_image() ) {
			$classes[] = 'custom-background-image';
		}
		// Adds a class of group-blog to sites with more than 1 published author.
		if ( is_multi_author() ) {
			$classes[] = 'group-blog';
		}
		// Adds a class of theme version.
		$classes[] = 'blogolife-'.str_replace('.','_', blogolife_get_theme_version() );

		// Adds a class of user browser.
		if( $is_lynx ) {
			$classes[] = 'lynx';
		} elseif($is_gecko) {
			$classes[] = 'gecko';
		} elseif($is_opera) {
			$classes[] = 'opera';
		} elseif($is_NS4) {
			$classes[] = 'ns4';
		} elseif($is_safari) {
			$classes[] = 'safari';
		} elseif($is_chrome) {
			$classes[] = 'chrome';
		} elseif($is_IE) {
			$classes[] = 'ie';
		} else {
			$classes[] = 'unknown';
		}

		// Adds a class for iphone.
		if($is_iphone) {
			$classes[] = 'iphone';
		}

		return $classes;
	}
endif;
add_filter( 'body_class', 'blogolife_body_classes' );


/*------------------------------------------------------------
	Attachment
============================================================*/
if ( ! function_exists( 'blogolife_get_attachment_by_size' ) ) :
	function blogolife_get_attachment_by_size ( $thumb_id, $size_name, $min_img_size) {
		$thumb_img = false;
		$img_src = wp_get_attachment_image_src( $thumb_id , $size_name );
		if ($img_src[1] >= $min_img_size) {
			$thumb_img = $img_src;
		}
		return $thumb_img;
	}
endif;
