<?php
/**
 * A widget with "Latest posts", "Latest Comments" and "Popular posts"
 *
 * @package WordPress
 * @subpackage BlogoLife
 * @since BlogoLife 3.0.0
 * @author Valeriu Tihai
 * @author Stylish WordPress Themes
 * @link https://stylishwp.com
 */

add_action('widgets_init', create_function('', 'return register_widget("Blogolife_Tab_Widget");'));

class Blogolife_Tab_Widget extends WP_Widget {

	public function __construct() {
		parent::__construct(
	 		'Blogolife_Tab_Widget',
			__( 'Tab Widget (StylishWP)', 'blogolife' ),
			array( 'description' => __( 'A widget with "Latest posts", "Latest Comments" and "Popular posts"', 'blogolife' ), )
		);
	}


	function form($instance) {
	// outputs the options form on admin
		if ( $instance ) {
			$number_of_posts = esc_attr( $instance[ 'number_of_posts' ] );
			$number_of_recent_comments = esc_attr( $instance[ 'number_of_recent_comments' ] );
			$number_of_popular_posts = esc_attr( $instance[ 'number_of_popular_posts' ] );
		}
		else {
			$number_of_posts = 10;
			$number_of_recent_comments = 5;
			$number_of_popular_posts = 10;
		}

		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id('number_of_posts') ); ?>">
				<?php _e('Number of Latest Posts:', 'blogolife'); ?>
			</label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('number_of_posts') ); ?>" name="<?php echo esc_attr( $this->get_field_name('number_of_posts') ); ?>" type="text" value="<?php echo esc_attr( $number_of_posts ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id('number_of_recent_comments') ); ?>">
				<?php _e('Number of recent comments:', 'blogolife'); ?>
			</label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('number_of_recent_comments') ); ?>" name="<?php echo esc_attr( $this->get_field_name('number_of_recent_comments') ); ?>" type="text" value="<?php echo esc_attr( $number_of_recent_comments ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id('number_of_popular_posts') ); ?>">
				<?php _e('Number of popular posts:', 'blogolife'); ?>
			</label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('number_of_popular_posts') ); ?>" name="<?php echo esc_attr( $this->get_field_name('number_of_popular_posts') ); ?>" type="text" value="<?php echo esc_attr( $number_of_popular_posts ); ?>" />
		</p>
		<?php
	}

	function update($new_instance, $old_instance) {
		// processes widget options to be saved
		$instance = $old_instance;
		$instance['number_of_posts'] = strip_tags($new_instance['number_of_posts']);
		$instance['number_of_recent_comments'] = strip_tags($new_instance['number_of_recent_comments']);
		$instance['number_of_popular_posts'] = strip_tags($new_instance['number_of_popular_posts']);
		return $instance;
	}

	function widget($args, $instance) {
		// outputs the content of the widget
		$number_of_posts = isset( $instance['number_of_posts'] ) ? (int)($instance['number_of_posts']) : 10;
		$number_of_recent_comments = isset( $instance['number_of_recent_comments'] ) ?( int)($instance['number_of_recent_comments']) : 5;
		$number_of_popular_posts = isset( $instance['number_of_popular_posts'] ) ? (int)($instance['number_of_popular_posts']) : 10;
	?>

	<!-- The tabs -->

<div id="tabs-widget-lcp" class="sidebar-section widget widget-lcp widget-lcp-<?php echo esc_attr($this->id); ?>">
	<div class="sidebar-section-title page-header blogolife-gradient">
		<ul class="tabs" data-tabs id="tabs-widget">
			<li class="tabs-title is-active"><a href="#lcp1-<?php echo esc_attr($this->id); ?>" aria-selected="true"><?php _e('Latest', 'blogolife'); ?></a></li>
			<li class="tabs-title"><a href="#lcp2-<?php echo esc_attr($this->id); ?>"><?php _e('Comments', 'blogolife'); ?></a></li>
			<li class="tabs-title"><a href="#lcp3-<?php echo esc_attr($this->id); ?>"><?php _e('Popular', 'blogolife'); ?></a></li>
		</ul>
	</div>

	<!-- tab "Latest Posts" -->
	<div class="tabs-content" data-tabs-content="tabs-widget">
		<div class="tabs-panel  tabs-panel-latest is-active" id="lcp1-<?php echo esc_attr($this->id); ?>">
			<ul>
				<?php
				// Check for transient. If none, then execute WP_Query
				$blogolife_latest_posts = get_transient( 'blogolife_latest_posts' );
				if ( false === $blogolife_latest_posts ) {
					//$blogolife_latest_posts = null;
					$blogolife_latest_posts = new WP_Query(
						array(
							'ignore_sticky_posts'=> 1,
							'post_type' => 'post',
							'post_status' => 'publish',
							'posts_per_page' => $number_of_posts
						));

					// Put the results in a transient. Expire after 1 hours.
					set_transient( 'blogolife_latest_posts', $blogolife_latest_posts, 1 * HOUR_IN_SECONDS );
				} ?>

				<?php if ( $blogolife_latest_posts->have_posts() ) : ?>

					<?php while ( $blogolife_latest_posts->have_posts() ) : $blogolife_latest_posts->the_post(); ?>
						<li><a href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></li>
					<?php endwhile; ?>

					<?php else: ?>
						<?php _e('No posts was found', 'blogolife'); ?>
				<?php endif; ?>

				<?php wp_reset_postdata(); ?>

			</ul>
		</div>

		<!-- tab "Recent Comments" -->
		<div class="tabs-panel  tabs-panel-comments" id="lcp2-<?php echo esc_attr($this->id); ?>">
			<ul>
				<?php
				$blogolife_comment_length = 120;
				$blogolife_count_avatar_comment = 0;
				$blogolife_latest_comments = get_transient( 'blogolife_latest_comments' );
				if (false === ($blogolife_latest_comments)) {
					$blogolife_latest_comments = get_comments(array('number'=> $number_of_recent_comments, 'status' => 'approve'));
					// Put the results in a transient. Expire after 1 hours.
					set_transient( 'blogolife_latest_comments', $blogolife_latest_comments, 1 * HOUR_IN_SECONDS );
				}

				if ($blogolife_latest_comments) {
					foreach ($blogolife_latest_comments as $comment)
				{ ?>
				<?php $blogolife_count_avatar_comment++; ?>
				<li>
					<?php echo get_avatar($comment,$size='50' ); ?><span class="commentr_author_title"><a href="<?php echo $comment->comment_author_url; ?>" rel="nofollow"><?php echo $comment->comment_author; ?></a></span>
					<p class="comment_content"><a href="<?php echo get_permalink( $comment->comment_post_ID ) . '#comment-' . $comment->comment_ID; ?>"><?php echo strip_tags(substr(apply_filters('get_comment_text', $comment->comment_content), 0, $blogolife_comment_length)); ?>...</a></p>
				</li>
				<?php } } else { echo "<li><?php _e('No comments yet!', 'blogolife'); ?></li>"; } ?>
			</ul>
		</div>

		<!-- tab "Popular" -->
		<div class="tabs-panel tabs-panel-popular" id="lcp3-<?php echo esc_attr($this->id); ?>">
			<ul>
				<?php
				// Check for transient. If none, then execute WP_Query
				$blogolife_popular_posts = get_transient( 'blogolife_popular_posts' );
				if ( false === $blogolife_popular_posts ) {
					//$blogolife_popular_posts = null;
					$blogolife_popular_posts = new WP_Query(
						array(
							'ignore_sticky_posts'=> 1,
							'post_type' => 'post',
							'post_status' => 'publish',
							'posts_per_page' => $number_of_popular_posts,
							'orderby' => 'comment_count'
						));

					// Put the results in a transient. Expire after 1 hours.
					set_transient( 'blogolife_popular_posts', $blogolife_popular_posts, 1 * HOUR_IN_SECONDS );
				} ?>

				<?php if ( $blogolife_popular_posts->have_posts() ) : ?>

					<?php while ( $blogolife_popular_posts->have_posts() ) : $blogolife_popular_posts->the_post(); ?>
						<li><a href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></li>
					<?php endwhile; ?>

					<?php else: ?>
						<?php _e('No popular posts was found', 'blogolife'); ?>
				<?php endif; ?>

				<?php wp_reset_postdata(); ?>
			</ul>
		</div>
	</div>
</div>
<?php	} } ?>
